@@ -179,7 +179,10 @@ class MapfwBenchmarker:
                 self.timeout = timeout
 
         else:
-            self.timeout = 0
+            if self.user_timeout:
+                self.timeout = self.user_timeout
+            else:
+                self.timeout = 0
 
         self.status = {"state": "RUNNING", "data": {"problem_states": [0 for _ in self.problems]}}
 
